#!/usr/bin/env python

# This program is free software; you can redistribute it and/or
# modify it under the terms of the GNU General Public License as
# published by the Free Software Foundation; either version 2 of the
# License, or (at your option) any later version.
# 
# Author : Nicolas Rougier
# Date   : 03/08/2007
# Version: beta

""" Float attribute renderer """

#________________________________________________________________________import
import gtk
import sys
from renderer import Renderer

#_________________________________________________________class ComplexRenderer
class ComplexRenderer (Renderer):
    """ Complex attribute renderer """
    
    #_________________________________________________________________ __init__
    def __init__ (self, attribute):
        """ Initialize renderer according to attribute """
        
        Renderer.__init__ (self, attribute)
        self.editable = gtk.HBox ()
        self.editable.set_spacing (6)
        self.real = gtk.Entry ()
        self.real.set_width_chars (6)        
        self.imag = gtk.Entry ()
        self.imag.set_width_chars (6)        
        self.editable.add (self.real)
        self.editable.add (self.imag)   
        self.set_value (self.attribute.get_value())
        self.signal_id1 = self.real.connect ('changed', self.on_change)
        self.signal_id2 = self.imag.connect ('changed', self.on_change)


    #_________________________________________________________________set_value
    def set_value (self, value):
        """ Set edited value to value """
        
        self.real.set_text (repr(value.real))
        self.imag.set_text (repr(value.imag))

    #_________________________________________________________________get_value
    def get_value (self):
        """ Get edited value """
        
        c = complex (0,0)
        self.bad_value = False   
        try:
            re = eval(self.real.get_text ())
            im = eval(self.imag.get_text ())            
        except:
            self.bad_value = True
        else:
            c = complex (re,im)
        return c

    #_____________________________________________________________________block
    def block (self):
        """ Block signal """

        self.real.handler_block (self.signal_id1)
        self.imag.handler_block (self.signal_id2)

    #___________________________________________________________________unblock
    def unblock (self):
        """ Unblock signal """

        self.real.handler_unblock (self.signal_id1)
        self.imag.handler_unblock (self.signal_id2)

    #________________________________________________________set_modified_state
    def set_modified_state (self, widget=None):
        """ Set renderer into modified state """
        
        Renderer.set_modified_state (self,self.real)
        Renderer.set_modified_state (self,self.imag)

    #______________________________________________________set_unmodified_state
    def set_unmodified_state (self, widget=None):
        """ Set renderer into unmodified state """
        
        Renderer.set_unmodified_state (self,self.real)
        Renderer.set_unmodified_state (self,self.imag)

