#!/usr/bin/env python

# This program is free software; you can redistribute it and/or
# modify it under the terms of the GNU General Public License as
# published by the Free Software Foundation; either version 2 of the
# License, or (at your option) any later version.
# 
# Author : Nicolas Rougier
# Date   : 03/08/2007
# Version: beta

""" Attribute Renderer
"""

#________________________________________________________________________import
import gtk
import sys

#________________________________________________________________class Renderer
class Renderer (object):
    """ Attribute renderer
    """
    
    #_________________________________________________________________ __init__
    def __init__ (self, attribute):
        """ Initialize renderer according to attribute """
        
        object.__init__ (self)
        self.attribute = attribute
        self.label = gtk.Label (self.attribute.label)
        self.label_use_markup = True
        self.label.set_alignment (1,0.5)
        self.editable = None
        self.bad_value = False
        self.view = None

    #__________________________________________________________________set_view
    def set_view (self, view):
        """ Set current view """

        self.view = view
        
    #_________________________________________________________________on_change
    def on_change (self, widget):
        """ Callback on value change """
        
        value = self.get_value () 
        self.attribute.set_edited_value (value)
        if self.get_value() != self.attribute.get_value():
            self.set_modified_state ()
        else:
            self.set_unmodified_state ()
        if self.view:
            self.view.notify()

    #_____________________________________________________________________apply
    def apply (self):
        """ Apply last change  """
        
        value = self.get_value ()
        self.attribute.set_value (value)
        self.attribute.set_edited_value (value)
        self.set_unmodified_state ()
        if self.view:
            self.view.notify()

    #______________________________________________________________________undo
    def undo (self):
        """ Undo last change """

        self.block()
        value = self.attribute.get_value ()
        edited_value = self.get_value()
        self.set_value (value)
        self.set_unmodified_state ()
        self.unblock()

    #______________________________________________________________________redo
    def redo (self):
        """ Redo last change """

        self.block()
        value = self.attribute.get_edited_value()
        self.set_value (value)
        if self.get_value() != self.attribute.get_value():
            self.set_modified_state ()
        self.unblock()

    #_____________________________________________________________________block
    def block (self):
        """ Block signal """

        self.editable.handler_block (self.signal_id)

    #___________________________________________________________________unblock
    def unblock (self):
        """ Unblock signal """

        self.editable.handler_unblock (self.signal_id)

    #________________________________________________________set_modified_state
    def set_modified_state (self, widget=None):
        """ Set renderer into modified state """

        if not widget:
            widget = self.editable
        m = widget.get_colormap()
        if not self.bad_value:
            color = m.alloc_color("#ffffdd")
        else:
            color = m.alloc_color("#ff9999")
        style = widget.get_style().copy()
        style.base[gtk.STATE_NORMAL] = color
        widget.set_style (style)

    #______________________________________________________set_unmodified_state
    def set_unmodified_state (self, widget=None):
        """ Set renderer into unmodified state """

        if not widget:
            widget = self.editable
        m = widget.get_colormap()
        color = m.alloc_color("#ffffff")
        style = widget.get_style().copy()
        style.base[gtk.STATE_NORMAL] = color
        widget.set_style (style)

