#!/usr/bin/env python

# This program is free software; you can redistribute it and/or
# modify it under the terms of the GNU General Public License as
# published by the Free Software Foundation; either version 2 of the
# License, or (at your option) any later version.
# 
# Author : Nicolas Rougier
# Date   : 03/08/2007
# Version: beta

""" View renderer """

#________________________________________________________________________import
import gtk
import sys
from renderer import Renderer

#____________________________________________________________class ViewRenderer
class ViewRenderer (Renderer):
    """ View renderer """
    
    #_________________________________________________________________ __init__
    def __init__ (self, attribute):
        """ Initialize renderer according to attribute """
        
        Renderer.__init__ (self, attribute)

        obj = getattr (self.attribute._object, self.attribute._name)
        self.attributes = getattr (obj,'attributes')
        self.editable = gtk.HBox()
        self.editable.set_spacing(6)
        self.renderers = []

        # Table for attribute renderers
        for attr in self.attributes:
            box = gtk.HBox()
            box.set_spacing(3)
            box.add (attr.renderer.label)
            box.add (attr.renderer.editable)
            self.renderers.append (attr.renderer)
            self.editable.add (box)
        self.editable.show_all()

    #__________________________________________________________________set_view
    def set_view (self, view):
        """ Set current view """

        for renderer in self.renderers:
            renderer.set_view (view)
    #_____________________________________________________________________apply
    def apply (self):
        """ Apply last change  """
        
        for renderer in self.renderers:
            renderer.apply()

    #______________________________________________________________________undo
    def undo (self):
        """ Undo last change """

        for renderer in self.renderers:
            renderer.undo()

    #______________________________________________________________________redo
    def redo (self):
        """ Redo last change """

        for renderer in self.renderers:
            renderer.redo()

    #_________________________________________________________________set_value
    def set_value (self, value):
        """ Set edited value to value """
        
        pass
        
    #_________________________________________________________________get_value
    def get_value (self):
        """ Get edited value """
        
        pass

    #_____________________________________________________________________block
    def block (self):
        """ Block signal """

        pass

    #___________________________________________________________________unblock
    def unblock (self):
        """ Unblock signal """

        pass

    #________________________________________________________set_modified_state
    def set_modified_state (self, widget=None):
        """ Set renderer into modified state """
        
        for renderer in self.renderers:
            renderer.set_modified_state()

    #______________________________________________________set_unmodified_state
    def set_unmodified_state (self, widget=None):
        """ Set renderer into unmodified state """
        
        for renderer in self.renderers:
            renderer.set_unmodified_state()

