#!/usr/bin/env python

# This program is free software; you can redistribute it and/or
# modify it under the terms of the GNU General Public License as
# published by the Free Software Foundation; either version 2 of the
# License, or (at your option) any later version.
# 
# Author : Nicolas Rougier
# Date   : 03/08/2007
# Version: beta

""" Attribute class.
"""

#________________________________________________________________________import
import gtk
import sys
from attribute import Attribute

#_________________________________________________________________________views


#____________________________________________________________________class View
class View(object):
    """
    """
    
    #_________________________________________________________________ __init__
    def __init__ (self, attributes, title = None):
        """ Initialize a new View """
        
        object.__init__(self)

        self.attributes = attributes

        # Main window
        self.window = gtk.Window()
        self.window.set_resizable (False)
        self.window.set_border_width (6)
        
        # Main vbox
        self.vbox = gtk.VBox(False,False)
        self.vbox.set_spacing (12)
        self.window.add (self.vbox)

        # Table for attribute renderers
        table = gtk.Table (len(attributes),2, False)
        table.set_col_spacings (12)
        table.set_row_spacings (3)
        group = gtk.SizeGroup (gtk.SIZE_GROUP_VERTICAL)
        row = 0
        for attr in self.attributes:
            attr.renderer.set_view (self)
            table.attach (attr.renderer.label, 0,1,row,row+1,
                          gtk.SHRINK |gtk.FILL, 0, 0, 0)
            table.attach (attr.renderer.editable, 1,2,row,row+1,
                          gtk.EXPAND |gtk.FILL, 0, 0, 0)
            group.add_widget(attr.renderer.editable)
            row += 1
        self.vbox.pack_start (table, False, True)

        # Window Buttons
        self.bbox = gtk.HButtonBox()
        self.bbox.set_layout (gtk.BUTTONBOX_END)
        self.buttons = {}
        self.buttons["ok"] = gtk.Button(stock=gtk.STOCK_OK)
        self.buttons["ok"].connect ('clicked', self.on_ok)
        self.buttons["apply"] = gtk.Button(stock=gtk.STOCK_APPLY)
        self.buttons["apply"].set_sensitive (False)
        self.buttons["apply"].connect ('clicked', self.on_apply)
        self.buttons["undo"] = gtk.Button(stock=gtk.STOCK_UNDO)
        self.buttons["undo"].set_sensitive (False)        
        self.buttons["undo"].connect ('clicked', self.on_undo)
        self.buttons["redo"] = gtk.Button(stock=gtk.STOCK_REDO)
        self.buttons["redo"].set_sensitive (False)
        self.buttons["redo"].connect ('clicked', self.on_redo)        
        self.bbox.pack_start (self.buttons["redo"])
        self.bbox.pack_start (self.buttons["undo"])
        self.bbox.pack_end (self.buttons["apply"])
        self.bbox.pack_end (self.buttons["ok"])
        self.vbox.pack_start (self.bbox, False, True)
        
        self.window.show_all()

    #__________________________________________________________________on_apply
    def on_apply (self, widget):
        """ Callback on apply button """

        for attr in self.attributes:
            attr.renderer.apply()
        for attr in self.attributes:
            attr.renderer.undo()
        self.buttons["undo"].set_sensitive (False)
        self.buttons["apply"].set_sensitive (False)
        self.buttons["redo"].set_sensitive (False)

    #___________________________________________________________________on_undo
    def on_undo (self, widget):
        """ Callback on undo button """

        for attr in self.attributes:
            attr.renderer.undo()
        self.buttons["undo"].set_sensitive (False)
        self.buttons["apply"].set_sensitive (False)
        self.buttons["redo"].set_sensitive (True)

    #___________________________________________________________________on_redo
    def on_redo (self, widget):
        """ Callback on redo button """

        for attr in self.attributes:
            attr.renderer.redo()
        self.buttons["undo"].set_sensitive (True)
        self.buttons["apply"].set_sensitive (True)
        self.buttons["redo"].set_sensitive (False)

    #_____________________________________________________________________on_ok
    def on_ok (self, widget):
        """ Callback on ok button """

        gtk.main_quit()

    #____________________________________________________________________notify
    def notify (self):
        """ Update view """

        self.buttons["apply"].set_sensitive (True)
        self.buttons["undo"].set_sensitive (True)

  
#_______________________________________________________________________example
if __name__ == '__main__':

    class Demo (object):
        """ Demo class """
        a_bool = True
        a_int = 1
        a_long = long(1.0)
        a_float = 1.0
        a_complex = complex(1.0,1.0)
        a_string = "Text"
        a_list = [1,2,3]
        a_dict = {"first":1, "second":2, "three":3}
        a_tuple = (1,2,3)
    
        def __init__(self):
            """ """
            object.__init__(self)

    demo = Demo()
    demo.a_demo = Demo()
    demo.a_demo.attributes = [
                              Attribute (demo, 'a_int'),
                              Attribute (demo, 'a_bool')
                             ]
    
    view = View ([
                  Attribute (demo, 'a_int'),
                  Attribute (demo, 'a_bool'),
                  Attribute (demo, 'a_long'),
                  Attribute (demo, 'a_float'),
                  Attribute (demo, 'a_complex'),
                  Attribute (demo, 'a_string'),
                  Attribute (demo, 'a_demo'),
                 ])
    gtk.main()
    
